@@ -62,10 +62,13 @@
 #include <hotspotcontroller.h>
 
 #include <networkmanagerqt/manager.h>
+#include <networkmanagerqt/wirelesssetting.h>
+#include <networkmanagerqt/setting.h>
 
 DWIDGET_USE_NAMESPACE
 using namespace dcc::widgets;
 using namespace dde::network;
+using namespace NetworkManager;
 
 APItem::APItem(const QString &text, QStyle *style, DListView *parent)
         : DStandardItem(text)
@@ -306,6 +309,7 @@ WirelessPage::WirelessPage(WirelessDevice *dev, QWidget *parent)
         , m_sortDelayTimer(new QTimer(this))
         , m_autoConnectHideSsid("")
         , m_wirelessScanTimer(new QTimer(this))
+        , m_isAirplaneMode(false)
 {
     setAccessibleName("WirelessPage");
     qRegisterMetaType<APSortInfo>();
@@ -352,11 +356,11 @@ WirelessPage::WirelessPage(WirelessDevice *dev, QWidget *parent)
     connect(m_switch, &SwitchWidget::checkedChanged, this, &WirelessPage::onNetworkAdapterChanged);
     connect(m_device, & WirelessDevice::enableChanged, this, [ this ] (const bool enabled) {
         m_switch->blockSignals(true);
-        m_switch->setChecked(enabled);
+        m_switch->setChecked(m_device->isEnabled() && !m_isAirplaneMode);
         m_switch->blockSignals(false);
         if (m_lvAP) {
             onUpdateAPItem();
-            m_lvAP->setVisible(enabled && QGSettings("com.deepin.dde.control-center", QByteArray(), this).get("wireless").toString() != "Hidden");
+            m_lvAP->setVisible(enabled && !m_isAirplaneMode && QGSettings("com.deepin.dde.control-center", QByteArray(), this).get("wireless").toString() != "Hidden");
             updateLayout(!m_lvAP->isHidden());
         }
         if (!enabled)
@@ -511,8 +515,8 @@ void WirelessPage::onDeviceStatusChanged(const DeviceStatus &stat)
 
     WifiStatus curWifiStatus = unavailable ? Wifi_Unavailable : Wifi_Available;
     if (curWifiStatus != m_preWifiStatus && stat > DeviceStatus::Disconnected) {
-        m_switch->setChecked(!unavailable);
-        onNetworkAdapterChanged(!unavailable);
+        m_switch->setChecked(!unavailable && !m_isAirplaneMode);
+        onNetworkAdapterChanged(!unavailable && !m_isAirplaneMode);
         m_preWifiStatus = curWifiStatus;
     }
 
@@ -579,6 +583,7 @@ void WirelessPage::onUpdateAccessPointInfo(const QList<AccessPoints *> &changeAp
 void WirelessPage::onAirplaneModeChanged(bool airplaneModeEnabled)
 {
     setDisabled(airplaneModeEnabled);
+    setIsAirplaneMode(airplaneModeEnabled);
 }
 
 void WirelessPage::onUpdateAPItem()
@@ -656,6 +661,14 @@ void WirelessPage::appendConnectHidden()
     m_modelAP->appendRow(nonbc);
 }
 
+void WirelessPage::setIsAirplaneMode(bool isAirplaneMode)
+{
+    if(m_isAirplaneMode != isAirplaneMode){
+        m_switch->setChecked(m_device->isEnabled() && !isAirplaneMode);
+    }
+    m_isAirplaneMode = isAirplaneMode;
+}
+
 void WirelessPage::onHotspotEnableChanged(const bool enabled)
 {
     m_closeHotspotBtn->setVisible(enabled);
@@ -823,9 +836,20 @@ void WirelessPage::updateApStatus()
 QString WirelessPage::connectionUuid(const QString &ssid)
 {
     for (auto conn : NetworkManager::activeConnections()) {
-        if (conn->type() == ConnectionSettings::ConnectionType::Wireless &&  conn->id() == ssid) {
-            return conn->uuid();
-        }
+        if (conn->type() != ConnectionSettings::ConnectionType::Wireless || conn->id() != ssid)
+            continue;
+
+        NetworkManager::ConnectionSettings::Ptr connSettings = conn->connection()->settings();
+        NetworkManager::WirelessSetting::Ptr wSetting = connSettings->setting(NetworkManager::Setting::SettingType::Wireless).staticCast<NetworkManager::WirelessSetting>();
+        if (wSetting.isNull())
+            continue;
+
+        QString settingMacAddress = wSetting->macAddress().toHex().toUpper();
+        QString deviceMacAddress = m_device->realHwAdr().remove(":");
+        if (!settingMacAddress.isEmpty() && settingMacAddress != deviceMacAddress)
+            continue;
+
+        return conn->uuid();
     }
     const QList<WirelessConnection *> lstConnections = m_device->items();
     for (auto item : lstConnections) {
