@@ -279,7 +279,7 @@ void WiredItem::initUi()
                                                        QSize(20, 20), QSize(20, 20), false);
 
     m_connectionIconAction = new DViewItemAction(Qt::AlignLeft | Qt::AlignVCenter,
-                                                 QSize(20, 20), QSize(20, 20), false);
+                                                 QSize(20, 20), QSize(8, 20), false);
 
     standardItem()->setActionList(Qt::LeftEdge, { emptyAction, m_connectionIconAction });
     updateView();
@@ -394,7 +394,7 @@ void WirelessItem::initUi(QWidget *parent)
     m_securityAction = new DViewItemAction(Qt::AlignLeft , QSize(20, 35), QSize(20, 35), false);
     updateSrcirityIcon();
     // 绘制WiFi图标
-    m_wifiLabel = new DViewItemAction(Qt::AlignLeft , QSize(20, 35), QSize(20, 35), false);
+    m_wifiLabel = new DViewItemAction(Qt::AlignLeft , QSize(20, 35), QSize(8, 35), false);
     updateWifiIcon();
 
     standardItem()->setSizeHint(QSize(-1, 36));
@@ -479,13 +479,15 @@ void WirelessItem::expandWidget(ExpandWidget type, bool autoDisconnect)
 {
     switch (type) {
     case ExpandWidget::Hide:
-        m_expandItem->setVisible(false);
-        m_topItem->setVisible(false);
-        standardItem()->setSizeHint(QSize(-1, 36));
-        if (m_accessPoint) {
-            LocalClient::instance()->changePassword(m_accessPoint->ssid(), QString(), false);
-            if(autoDisconnect && m_accessPoint->status() == ConnectionStatus::Activating) {
-                m_device->disconnectNetwork();
+        if(m_expandItem->isVisible()) {
+            m_expandItem->setVisible(false);
+            m_topItem->setVisible(false);
+            standardItem()->setSizeHint(QSize(-1, 36));
+            if (m_accessPoint) {
+                LocalClient::instance()->changePassword(m_accessPoint->ssid(), QString(), false);
+                if(autoDisconnect && m_accessPoint->status() == ConnectionStatus::Activating) {
+                    m_device->disconnectNetwork();
+                }
             }
         }
         break;
@@ -669,10 +671,35 @@ bool WirelessItem::expandVisible()
     return m_expandItem->isVisible();
 }
 
+const QDateTime WirelessItem::timeStamp(WirelessConnection *connection) const
+{
+    NetworkManager::Connection::Ptr connect(new NetworkManager::Connection(connection->connection()->path()));
+    return connect->settings()->timestamp();
+}
+
 void WirelessItem::onCancel()
 {
     if (m_accessPoint && m_accessPoint->status() == ConnectionStatus::Activating) {
         m_device->disconnectNetwork();
+        QList<WirelessConnection *> connections = m_device->items();
+        // 断开连接后，找到最后一次连接的热点
+        WirelessConnection *lastConnection = nullptr;
+        for (WirelessConnection *conn : connections) {
+            if (conn->accessPoints() == m_accessPoint)
+                continue;
+
+            QDateTime ts = timeStamp(conn);
+            if (!ts.isValid())
+                continue;
+
+            if (!lastConnection || timeStamp(lastConnection) < ts)
+                lastConnection = conn;
+        }
+
+        if (lastConnection)
+            m_device->connectNetwork(lastConnection->accessPoints());
+
     }
+
     this->expandWidget(ExpandWidget::Hide);
 }
