@@ -26,19 +26,23 @@
 
 #include <QJsonDocument>
 #include <QJsonObject>
-#include <QCoreApplication>
+#include <QApplication>
 #include <QTimer>
 #include <QProcess>
 #include <QFile>
 
 #include <networkcontroller.h>
+#include <DRegionMonitor>
+
+DGUI_USE_NAMESPACE
 
 const QString NetworkDialogApp = "dde-network-dialog"; //网络列表执行文件
 static QMap<QString, void (LocalClient::*)(QLocalSocket *, const QByteArray &)> s_FunMap = {
     { "showPosition", &LocalClient::showPosition },
     { "connect", &LocalClient::connectNetwork },
     { "password", &LocalClient::receivePassword },
-    { "receive", &LocalClient::receive }
+    { "receive", &LocalClient::receive },
+    { "click", &LocalClient::onClick}
 };
 
 LocalClient::LocalClient(QObject *parent)
@@ -48,19 +52,31 @@ LocalClient::LocalClient(QObject *parent)
     , m_exitTimer(new QTimer(this))
     , m_popopWindow(nullptr)
     , m_panel(nullptr)
+    , m_translator(nullptr)
+    , m_popopNeedShow(false)
 {
     m_clinet = new QLocalSocket(this);
     connect(m_clinet, SIGNAL(connected()), this, SLOT(connectedHandler()));
     connect(m_clinet, SIGNAL(disconnected()), this, SLOT(disConnectedHandler()));
     connect(m_clinet, SIGNAL(readyRead()), this, SLOT(readyReadHandler()));
-    connect(m_exitTimer, SIGNAL(timeout()), qApp, SLOT(quit()));
+    connect(m_exitTimer, &QTimer::timeout, this, [] {
+        qApp->quit();
+    });
     ConnectToServer();
+    updateTranslator(QLocale::system().name());
+
+    connect(qApp, &QApplication::aboutToQuit, this, [ this ] {
+        delete this;
+    });
 }
 
 LocalClient::~LocalClient()
 {
+    changePassword("","",false);
     m_clinet->disconnectFromServer();
     delete m_clinet;
+    if (m_panel)
+        delete m_panel;
 }
 
 void LocalClient::connectedHandler()
@@ -148,18 +164,48 @@ void LocalClient::showWidget()
     initWidget();
 }
 
+void LocalClient::showPopupWindow(bool forceShowDialog)
+{
+    static bool isShowing = false;
+    QPoint pt = m_popopWindow->property("localpos").toPoint();
+    if (pt.x() >= 0 && pt.y() >= 0 && m_popopNeedShow && (!isShowing || forceShowDialog)) {
+        m_popopWindow->show(pt, true);
+        isShowing = true;
+    }
+}
+
 void LocalClient::initWidget()
 {
     if (!m_popopWindow) {
         m_popopWindow = new DockPopupWindow();
+        m_popopWindow->setProperty("localpos", QPoint(-1, -1));
         m_panel = new NetworkPanel(m_popopWindow);
-        m_popopWindow->setContent(m_panel->itemApplet());
         QObject::connect(qApp, &QCoreApplication::destroyed, m_popopWindow, &DockPopupWindow::deleteLater);
-        QObject::connect(m_popopWindow, &DockPopupWindow::hideSignal, qApp, &QCoreApplication::quit);
+        QObject::connect(m_popopWindow, &DockPopupWindow::hideSignal, this, [] {
+            qApp->quit();
+        });
         QObject::connect(m_popopWindow, &DockPopupWindow::hideSignal, m_popopWindow, &DockPopupWindow::deleteLater);
+        QObject::connect(m_panel, &NetworkPanel::updateFinished, this, [ this ] {
+            m_popopNeedShow = true;
+            showPopupWindow();
+        });
     }
 }
 
+void LocalClient::updateTranslator(QString locale)
+{
+    if (m_locale == locale)
+        return;
+    if (m_translator) {
+        QApplication::removeTranslator(m_translator);
+        m_translator->deleteLater();
+    }
+    m_locale = locale;
+    m_translator = new QTranslator;
+    m_translator->load("/usr/share/dde-network-dialog/translations/dde-network-dialog_" + m_locale);
+    QApplication::installTranslator(m_translator);
+}
+
 void LocalClient::showPosition(QLocalSocket *socket, const QByteArray &data)
 {
     Q_UNUSED(socket)
@@ -174,15 +220,15 @@ void LocalClient::showPosition(QLocalSocket *socket, const QByteArray &data)
         if (locale.isEmpty())
             locale = QLocale::system().name();
 
-        if (!m_popopWindow) {
-            QTranslator *translator = new QTranslator;
-            translator->load("/usr/share/dde-network-dialog/translations/dde-network-dialog_" + locale);
-            qApp->installTranslator(translator);
-        }
+        updateTranslator(locale);
+
+        QPixmap pixmap;
         switch (reason) {
         case Greeter:
             dde::network::NetworkController::setServiceType(dde::network::ServiceLoadType::LoadFromManager);
             ThemeManager::instance()->setThemeType(ThemeManager::GreeterType);
+            if (!m_popopWindow)
+                pixmap = QPixmap::grabWindow(QApplication::desktop()->winId());
             break;
         case Lock:
             ThemeManager::instance()->setThemeType(ThemeManager::LockType);
@@ -191,11 +237,17 @@ void LocalClient::showPosition(QLocalSocket *socket, const QByteArray &data)
             break;
         }
         initWidget();
-        if (reason != Dock) {
-            m_popopWindow->setWindowFlag(Qt::Popup);
+        if (!pixmap.isNull()) {
+            m_popopWindow->setBackground(pixmap.toImage());
         }
+        bool forceShowDialog = false;
+        if (obj.contains("force"))
+            forceShowDialog = obj.value("force").toBool();
+
         m_popopWindow->setArrowDirection(static_cast<DArrowRectangle::ArrowDirection>(position));
-        m_popopWindow->show(QPoint(x, y), true);
+        m_popopWindow->setProperty("localpos", QPoint(x, y));
+        m_popopWindow->setContent(m_panel->itemApplet());
+        showPopupWindow(forceShowDialog);
     }
 }
 
@@ -219,16 +271,18 @@ void LocalClient::receivePassword(QLocalSocket *socket, const QByteArray &data)
     if (m_wait == WaitClient::Self) {
         QJsonDocument doc = QJsonDocument::fromJson(data);
         if (doc.isObject()) {
+            int exitCode = -4;
             QFile file;
-            if (!file.open(stdout, QFile::WriteOnly)) {
+            if (file.open(stdout, QFile::WriteOnly)) {
+                file.write("\npassword:" + data + "\n");
+                file.flush();
+                file.close();
+                m_ssid.clear();
+                exitCode = (doc.object().value("input").toBool() ? 0 : 1);
+            } else {
                 qInfo() << "open STDOUT failed";
-                qApp->exit(-4);
             }
-            file.write("\npassword:" + data + "\n");
-            file.flush();
-            file.close();
-            m_ssid.clear();
-            qApp->exit(doc.object().value("input").toBool() ? 0 : 1);
+            qApp->exit(exitCode);
         }
     }
 }
@@ -246,6 +300,20 @@ void LocalClient::receive(QLocalSocket *socket, const QByteArray &data)
     }
 }
 
+void LocalClient::onClick(QLocalSocket *socket, const QByteArray &data)
+{
+    Q_UNUSED(socket);
+    if (!m_popopWindow)
+        return;
+
+    QJsonDocument json = QJsonDocument::fromJson(data);
+    QJsonObject clickPos = json.object();
+    int x = clickPos.value("x").toInt();
+    int y = clickPos.value("y").toInt();
+
+    m_popopWindow->onGlobMouseRelease(QPoint(x, y), DRegionMonitor::WatchedFlags::Button_Left);
+}
+
 bool LocalClient::changePassword(QString key, QString password, bool input)
 {
     QJsonObject json;
