@@ -27,6 +27,16 @@
 
 using namespace dde::network;
 
+#define UNKNOW_MODE 0
+#define ADHOC_MODE  1
+#define INFRA_MODE 2
+#define AP_MODE 3
+
+#define ACTIVATING 1
+#define ACTIVATED 2
+#define DEACTIVATING 3
+#define DEACTIVATED 4
+
 const QStringList DeviceInterRealize::ipv4()
 {
     if (!isConnected() || !isEnabled())
@@ -83,7 +93,7 @@ QJsonObject DeviceInterRealize::activeConnectionInfo() const
 
 QStringList DeviceInterRealize::getValidIPV4(const QStringList &ipv4s)
 {
-    if (ipv4s.size() > 1)
+    if (ipv4s.size() > 1 || ipv4s.size() == 0)
         return ipv4s;
 
     // 检查IP列表，如果发现有IP为0.0.0.0，则让其重新获取一次，保证IP获取正确
@@ -193,20 +203,6 @@ void DeviceInterRealize::setDeviceEnabledStatus(const bool &enabled)
     Q_EMIT enableChanged(enabled);
 }
 
-void DeviceInterRealize::updateActiveInfo(const QList<QJsonObject> &info)
-{
-    // 更新活动连接信息，查找当前的设备的最新的状态
-    // 这里无需向外发送connectionChanged()信号，因为连接发生变化后，紧接着会获取IP地址等信息，
-    // 获取IP地址信息是一个异步过程，所以它将会最后发送
-    for (const QJsonObject &activeInfo : info) {
-        int activeStatus = activeInfo.value("State").toInt();
-        if (activeStatus == static_cast<int>(ConnectionStatus::Activated)) {
-            setDeviceStatus(DeviceStatus::Activated);
-            break;
-        }
-    }
-}
-
 void DeviceInterRealize::updateActiveConnectionInfo(const QList<QJsonObject> &infos)
 {
     PRINT_INFO_MESSAGE("receive Ip Data");
@@ -241,6 +237,24 @@ void DeviceInterRealize::updateActiveConnectionInfo(const QList<QJsonObject> &in
         Q_EMIT ipV4Changed();
 }
 
+void DeviceInterRealize::setDeviceStatus(const DeviceStatus &status)
+{
+    // 如果是开启热点，就让其renweus断开的状态
+    DeviceStatus stat = status;
+    if (mode() == AP_MODE)
+        stat = DeviceStatus::Disconnected;
+
+    NetworkDeviceRealize::setDeviceStatus(stat);
+}
+
+int DeviceInterRealize::mode() const
+{
+    if (m_data.contains("Mode"))
+        return m_data.value("Mode").toInt();
+
+    return UNKNOW_MODE;
+}
+
 /**
  * @brief 有线设备类的具体实现
  */
@@ -324,7 +338,7 @@ void WiredDeviceInterRealize::updateConnection(const QJsonArray &info)
             conn = new WiredConnection;
             m_connections << conn;
             newWiredConnections << conn;
-            PRINT_DEBUG_MESSAGE(QString("new wifi: %1").arg(jsonObj.value("Ssid").toString()));
+            PRINT_DEBUG_MESSAGE(QString("new connection ssid: %1").arg(jsonObj.value("Ssid").toString()));
         } else {
             if (conn->connection()->id() != jsonObj.value("Id").toString()
                     || conn->connection()->ssid() != jsonObj.value("Ssid").toString())
@@ -374,16 +388,16 @@ WiredConnection *WiredDeviceInterRealize::findWiredConnectionByUuid(const QStrin
 
 static ConnectionStatus convertStatus(int status)
 {
-    if (status == 1)
+    if (status == ACTIVATING)
         return ConnectionStatus::Activating;
 
-    if (status == 2)
+    if (status == ACTIVATED)
         return ConnectionStatus::Activated;
 
-    if (status == 3)
+    if (status == DEACTIVATING)
         return ConnectionStatus::Deactivating;
 
-    if (status == 4)
+    if (status == DEACTIVATED)
         return ConnectionStatus::Deactivated;
 
     return ConnectionStatus::Unknown;
@@ -436,12 +450,7 @@ bool WirelessDeviceInterRealize::isConnected() const
 
 QList<AccessPoints *> WirelessDeviceInterRealize::accessPointItems() const
 {
-    /* 理论上，如果网卡是禁用状态，这里应该直接返回空列表
-     * 但是由于在禁用网卡或者打开网卡的时候，后台的反应比较慢，控制中心无法实时获取，所以这里暂时让其先返回所有的网络列表，
-     * 等后台反应慢的问题改好后，再把注释打开
-     * if (!isEnabled())
-        return QList<UAccessPoints *>();*/
-    if (m_hotspotInfo.isEmpty())
+    if (needShowAccessPoints())
         return m_accessPoints;
 
     return QList<AccessPoints *>();
@@ -545,6 +554,9 @@ AccessPoints *WirelessDeviceInterRealize::findAccessPoint(const QString &ssid)
 
 WirelessConnection *WirelessDeviceInterRealize::findConnectionByAccessPoint(const AccessPoints *accessPoint)
 {
+    if (!accessPoint)
+        return Q_NULLPTR;
+
     for (WirelessConnection *connection : m_connections) {
         if (connection->accessPoints() == accessPoint)
             return connection;
@@ -644,6 +656,15 @@ QList<WirelessConnection *> WirelessDeviceInterRealize::wirelessItems() const
     return m_connections;
 }
 
+bool WirelessDeviceInterRealize::needShowAccessPoints() const
+{
+    // Mode=3表示开启热点
+    if (mode() == AP_MODE)
+        return false;
+    // 如果当前设备热点为空(关闭热点)，则让显示所有的网络列表
+    return m_hotspotInfo.isEmpty();
+}
+
 void WirelessDeviceInterRealize::updateActiveConnectionInfo(const QList<QJsonObject> &infos)
 {
     bool enabledHotspotOld = hotspotEnabled();
